From ec721c8e80b9ed09a9cbbf653defa1e265ad7b8c Mon Sep 17 00:00:00 2001
From: David Lawrence Ramsey <pooka109@gmail.com>
Date: Wed, 7 Jul 2004 15:20:52 +0000
Subject: [PATCH] another missing piece of DB's patch: the toggle and rcoption
 structs should use longs to store their flags too

git-svn-id: svn://svn.savannah.gnu.org/nano/trunk/nano@1846 35c25a1d-7b9e-4130-9fde-d3aeb78583b8
---
 src/nano.h | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/nano.h b/src/nano.h
index 26ef24b5..db5678a6 100644
--- a/src/nano.h
+++ b/src/nano.h
@@ -34,7 +34,7 @@
 #include <limits.h>
 #endif
 
 /* Macros for the flags int... */
 #define SET(bit) flags |= bit
 #define UNSET(bit) flags &= ~bit
 #define ISSET(bit) ((flags & bit) != 0)
@@ -194,7 +194,7 @@ typedef struct toggle {
    const char *desc;	/* Description for when toggle is, uh, toggled,
 			 * e.g. "Cut to end"; we'll append Enabled or
 			 * Disabled. */
-   int flag;		/* What flag actually gets toggled. */
+   long flag;		/* What flag actually gets toggled. */
    struct toggle *next;
 } toggle;
 #endif /* !NANO_SMALL */
@@ -202,7 +202,7 @@ typedef struct toggle {
 #ifdef ENABLE_NANORC
 typedef struct rcoption {
    const char *name;
-   int flag;
+   long flag;
 } rcoption;
 #endif /* ENABLE_NANORC */
 
@@ -34,7 +34,7 @@
 #endif
 
-/* Macros for the flags int... */
+/* Macros for the flags long... */
 #define SET(bit) flags |= bit
 #define UNSET(bit) flags &= ~bit
-- 
GitLab